<?php

/***************************************************************************
 * 
 *  Name: Simple Social Module
 *  URI: http://jcore.net
 *  Description: Add 12+ social icons to your posts or even Facebook and Twitter widgets to share your posts in the social networks.
 *  Author: Istvan Petres
 *  Version: 1.0
 *  Tags: simple social module, posts, gpl, lgpl, mpl 
 * 
 ****************************************************************************/

class simpleSocial extends modules {
	var $availableButtons = array(
		'fb' => 'Facebook',
		'tw' => 'Twitter',
		'em' => 'Email',
		'bg' => 'Blogger',
		'dl' => 'Delicious',
		'dg' => 'Digg',
		'go' => 'Google',
		'ms' => 'My Space',
		'su' => 'Stumble Uppon',
		'yh' => 'Yahoo',
		'rd' => 'Reddit',
		'tr' => 'Technorati',
		'rs' => 'RSS');
	
	var $availableWidgets = array(
		'fb' => 'Facebook',
		'tw' => 'Twitter');
	
	var $adminPath = 'admin/modules/simplesocial';
	
	function __construct() {
		languages::load('simplesocial');
	}
	
	function __destruct() {
		languages::unload('simplesocial');
	}
	
	function installSQL() {
		sql::run(
			"CREATE TABLE IF NOT EXISTS `{simplesocial}` (" .
			" `ID` varchar(100) NOT NULL default ''," .
			" `Value` varchar(255) NOT NULL default ''," .
			" PRIMARY KEY  (`ID`)" .
			" ) ENGINE=MyISAM;");
		
		if (sql::error())
			return false;
		
		return true;
	}
	
	function installFiles() {
		$css = 
			"div.simplesocial-buttons {\n" .
			"	padding: 15px 0;\n" .
			"}\n" .
			"\n" .
			"div.simplesocial,\n" .
			"a.simplesocial\n" .
			"{\n" .
			"	float: left;\n" .
			"	display: block;\n" .
			"}\n" .
			"\n" .
			"a.simplesocial {\n" .
			"	margin-right: 5px !important;\n" .
			"	width: 16px;\n" .
			"	height: 16px;\n" .
			"	padding: 0 !important;\n" .
			"}\n" .
			"\n" .
			"a.simplesocial:hover {\n" .
			"	margin-top: -2px;\n" .
			"}\n";
		
		if (!files::save(SITE_PATH.'template/modules/css/simplesocial.css', $css))
			return false;
		
		$js = 
			"function simplesocial(t,w,h) {\n" .
			"	window.open(t.href, 'simplesocial', 'scrollbars=1,menubar=0,width='+w+',height='+h+',resizable=1,toolbar=0,location=0,status=0,left='+(screen.width-w)/2+',top='+(screen.height-h)/3);\n" .
			"	return false;\n" .
			"}\n";
		
		if (!files::save(SITE_PATH.'template/modules/js/simplesocial.js', $js))
			return false;
		
		return true;
	}
	
	function uninstallSQL() {
		return
			sql::run(
				" DROP TABLE IF EXISTS `{simplesocial}`;");
	}
	
	function uninstallFiles() {
		return 
			files::delete(SITE_PATH.'template/modules/css/simplesocial.css');
	}
	
	// ************************************************   Admin Part
	function setupAdmin() {
		favoriteLinks::add(
			__('Pages / Posts'), 
			'?path=admin/content/pages');
	}
	
	function verifyAdmin(&$form = null) {
		if (!$form->verify())
			return false;
		
		if (!$this->saveSettings($form->getPostArray()))
			return false;
		
		tooltip::display(
			__("Settings have been successfully saved."),
			TOOLTIP_SUCCESS);
		
		return true;
	}
	
	function displayAdmin() {
		admin::displayTitle(_('Simple Social Module'));
		
		echo
			"<div class='admin-content'>";
		
		$form = new form(
				_("Simple Social Settings"),
				'settingsform');
		
		$form->add(
			_('Display Buttons'),
			'Buttons',
			FORM_INPUT_TYPE_CHECKBOX);
		$form->setValueType(FORM_VALUE_TYPE_ARRAY);
		
		foreach($this->availableButtons as $buttonid => $button)
			$form->addValue($buttonid, $button);
		
		$form->add(
			_('Display Widgets'),
			'Widgets',
			FORM_INPUT_TYPE_CHECKBOX);
		$form->setValueType(FORM_VALUE_TYPE_ARRAY);
		
		foreach($this->availableWidgets as $widgetid => $widget)
			$form->addValue($widgetid, $widget);
		
		$form->add(
			_('Select Page(s) to Display on'),
			'PageIDs',
			FORM_INPUT_TYPE_MULTISELECT);
		$form->setValueType(FORM_VALUE_TYPE_ARRAY);
		$form->setStyle('width: 90%; height: 250px;');
		
		foreach(pages::getTree() as $page)
			$form->addValue($page['ID'], 
				($page['SubPageOfID']?
					str_replace(' ', '&nbsp;', 
						str_pad('', $page['PathDeepnes']*4, ' ')).
					"|- ":
					null) .
				$page['Title']);
		
		$form->groupValues(array('0'));
		
		$form->addSubmitButtons();
		
		$verifyok = false;
		
		if ($this->userPermissionType & USER_PERMISSION_TYPE_WRITE)
			$verifyok = $this->verifyAdmin($form);
		
		if ($this->userPermissionType & USER_PERMISSION_TYPE_WRITE) {
			if ($verifyok || !$form->submitted()) {
				$settings = $this->getSettings();
				
				$form->setValue(
					'Buttons', 
					(isset($settings['Buttons'])?
						$settings['Buttons']:
						array_keys($this->availableButtons)));
				
				$form->setValue('Widgets', 
					(isset($settings['Widgets'])?
						$settings['Widgets']:
						null));
				
				$form->setValue('PageIDs',
					(isset($settings['PageIDs'])?
						$settings['PageIDs']:
						null));
			}
			
			echo
				"<a name='adminform'></a>";
			
			$form->display();
		}
		
		unset($form);
		
		echo 
			"</div>";	//admin-content
	}
	
	function saveSettings($values) {
		if (!is_array($values))
			return false;
		
		foreach($values as $valueid => $value) {
			if (!in_array($valueid, array('Buttons', 'Widgets', 'PageIDs')))
				continue;
			
			if (is_array($value))
				$value = implode('|', (array)$value);
			
			$exists = sql::fetch(sql::run(
				" SELECT `ID` FROM `{simplesocial}`" .
				" WHERE `ID` = '".sql::escape((string)$valueid)."'"));
			
			if ($exists) {
				sql::run(
					" UPDATE `{simplesocial}` SET ".
					" `Value` = '".
						sql::escape($value)."'" .
					" WHERE `ID` = '".sql::escape((string)$valueid)."'");
				
				if (sql::affected() == -1) {
					tooltip::display(
						sprintf(_("Settings couldn't be saved! Error: %s"), 
							sql::error()),
						TOOLTIP_ERROR);
					return false;
				}
				
			} else {
				$newid = sql::run(
					" INSERT INTO `{simplesocial}` SET ".
					" `Value` = '".
						sql::escape($value)."'," .
					" `ID` = '".
						sql::escape((string)$valueid)."'");
				
				if (sql::affected() == -1) {
					tooltip::display(
						sprintf(_("Settings couldn't be saved! Error: %s"), 
							sql::error()),
						TOOLTIP_ERROR);
					return false;
				}
			}
		}
		
		return true;
	}
	
	// ************************************************   Client Part
	function getSettings() {
		$rows = sql::run(
			" SELECT * FROM `{simplesocial}`");
		
		$settings = null;
		while($row = sql::fetch($rows)) {
			if (trim($row['Value']))
				$settings[$row['ID']] = explode('|', $row['Value']);
			else
				$settings[$row['ID']] = array();
		}
		
		return $settings;
	}
	
	function displayButtons($env, $post) {
		$simplesocial_permlink = $post['_Link'];
		$simplesocial_enclink = urlencode($simplesocial_permlink);
		$simplesocial_title = urlencode($post['Title']);
		$simplesocial_dir = url::site().'lib/modules/simplesocial/icons_16/';
		
		$settings = $this->getSettings();
		
		if (count($settings['PageIDs']) && !in_array(pages::$selected['ID'], $settings['PageIDs']))
			return;
		
		if (!isset($settings['Buttons']))
			$settings['Buttons'] = array_keys($this->availableButtons);
		
		echo
			'<div class="simplesocial-buttons">';
		
		// Twitter widget
		if(isset($settings['Widgets']) && in_array('tw', $settings['Widgets']))
			echo
				'<div class=simplesocial>' .
					'<a href="http://twitter.com/share" ' .
						'data-url="'.$simplesocial_permlink.'" ' .
						'data-text="'.$simplesocial_title.'" ' .
						'class="twitter-share-button" ' .
						'data-count="horizontal">' .
						'Tweet' .
					'</a>' .
					'<script type="text/javascript" ' .
						'src="http://platform.twitter.com/widgets.js">' .
					'</script>' .
				'</div>';

		// Facebook widget
		if(isset($settings['Widgets']) && in_array('fb', $settings['Widgets']))
			echo
				'<div class=simplesocial>' .
				'<iframe src="http://www.facebook.com/plugins/like.php?' .
					'href='.$simplesocial_enclink.'&' .
					'layout=standard&show_faces=false&width=450&' .
					'action=like&colorscheme=light&height=35" ' .
					'scrolling="no" frameborder="0" ' .
					'style="border:none; overflow:hidden; width:450px; height:25px;" ' .
					'allowTransparency="true"></iframe>' .
				'</div>';
		
		// New Line
		echo '<div class="clear-both"></div>';
		
		// Facebook Button
		if(in_array('fb', $settings['Buttons']))
			echo 
				'<a class=simplesocial onclick="return simplesocial(this,500,400)" ' .
					'title="Share on Facebook" ' .
					'style="background:url('.$simplesocial_dir.'facebook.png)" ' .
					'href="http://www.facebook.com/share.php?u='.$simplesocial_enclink.'&' .
						't='.$simplesocial_title.'">' .
				'</a>';
		
		// Twitter Button
		if(in_array('tw', $settings['Buttons']))
			echo
				'<a class=simplesocial onclick="return simplesocial(this,812,420)" ' .
					'title="Share on Twitter" ' .
					'style="background:url('.$simplesocial_dir.'twitter.png)" ' .
					'href="http://twitter.com/home?status='.$simplesocial_enclink.'">' .
				'</a>';
		
		// Email Button
		if(in_array('em', $settings['Buttons']))
			echo
				'<a class=simplesocial onclick="return simplesocial(this,435,500)" ' .
					'title="Email a Friend" ' .
					'style="background:url('.$simplesocial_dir.'email.png)" ' .
					'href="http://www.freetellafriend.com/tell/?heading=Share+This+Article&' .
						'bg=1&option=email&url='.$simplesocial_enclink.'">' .
				'</a>';
		
		// Blogger Button
		if(in_array('bg', $settings['Buttons']))
			echo
				'<a class=simplesocial onclick="return simplesocial(this,750,500)" ' .
					'title="Share on Blogger" ' .
					'style="background:url('.$simplesocial_dir.'blogger.png)" ' .
					'href="http://www.blogger.com/blog_this.pyra?' .
						't&u='.$simplesocial_enclink.'&n='.$simplesocial_title.'&pli=1">' .
				'</a>';
		
		// Delicious Button
		if(in_array('dl', $settings['Buttons']))
			echo
				'<a class=simplesocial onclick="return simplesocial(this,890,550)" ' .
					'title="Share on Delicious" ' .
					'style="background:url('.$simplesocial_dir.'delicious.png)" ' .
					'href="http://del.icio.us/post?url='.$simplesocial_enclink.'&' .
						'title='.$simplesocial_title.'">' .
				'</a>';
		
		// Digg Button
		if(in_array('dg', $settings['Buttons']))
			echo
				'<a class=simplesocial onclick="return simplesocial(this,812,420)" ' .
					'title="Share on Digg" ' .
					'style="background:url('.$simplesocial_dir.'digg.png)" ' .
					'href="http://digg.com/submit?url='.$simplesocial_enclink.'&' .
						'title='.$simplesocial_title.'">' .
				'</a>';

		// Google Button
		if(in_array('go', $settings['Buttons']))
			echo
				'<a class=simplesocial onclick="return simplesocial(this,750,500)" ' .
					'title="Share on Google" ' .
					'style="background:url('.$simplesocial_dir.'google.png)" ' .
					'href="http://www.google.com/bookmarks/mark?op=add&' .
						'bkmk='.$simplesocial_enclink.'&' .
						'title='.$simplesocial_title.'">' .
				'</a>';
		
		// Myspace Button
		if(in_array('ms', $settings['Buttons']))
			echo
				'<a class=simplesocial onclick="return simplesocial(this,812,420)" ' .
					'title="Share on Myspace" ' .
					'style="background:url('.$simplesocial_dir.'myspace.png)" ' .
					'href="http://www.myspace.com/Modules/PostTo/Pages/?' .
						'u='.$simplesocial_enclink.'&' .
						't='.$simplesocial_title.'&' .
						'c='.$simplesocial_enclink.'">' .
				'</a>';
		
		// StumbleUpon Button
		if(in_array('su', $settings['Buttons']))
			echo 
				'<a class=simplesocial onclick="return simplesocial(this,750,500)" ' .
					'title="Share on StumbleUpon" ' .
					'style="background:url('.$simplesocial_dir.'stumbleupon.png)" ' .
					'href="http://www.stumbleupon.com/submit?url='.$simplesocial_enclink.'&' .
						'title='.$simplesocial_title.'">' .
				'</a>';
		
		// Yahoo Button
		if(in_array('yh', $settings['Buttons']))
			echo
				'<a class=simplesocial onclick="return simplesocial(this,900,550)" ' .
					'title="Share on Yahoo" ' .
					'style="background:url('.$simplesocial_dir.'yahoo.png)" ' .
					'href="http://buzz.yahoo.com/buzz?targetUrl='.$simplesocial_enclink.'&' .
						'headline='.$simplesocial_title.'">' .
				'</a>';
		
		// Reddit Button
		if(in_array('rd', $settings['Buttons']))
			echo
				'<a class=simplesocial onclick="return simplesocial(this,700,500)" ' .
					'title="Share on Reddit" ' .
					'style="background:url('.$simplesocial_dir.'reddit.png)" ' .
					'href="http://reddit.com/submit?url='.$simplesocial_enclink.'&' .
						'title='.$simplesocial_title.'">' .
				'</a>';
		
		// Technorati Button
		if(in_array('tr', $settings['Buttons']))
			echo
				'<a class=simplesocial onclick="return simplesocial(this,812,500)" ' .
					'title="Share on Technorati" ' .
					'style="background:url('.$simplesocial_dir.'technorati.png)" ' .
					'href="http://technorati.com/faves?sub=favthis&' .
						'add='.$simplesocial_enclink.'">' .
				'</a>';

		// RSS Button
		if(in_array('rs', $settings['Buttons']))
			echo
				'<a class=simplesocial title="RSS Feed" target="_blank" ' .
					'style="background:url('.$simplesocial_dir.'rss.png)" ' .
					'href="'.url::site().'rss/posts.xml">' .
				'</a>';
		
		// End
		echo 
				'<div class="clear-both"></div>' .
			'</div>';
	}
}

modules::register(
	'simpleSocial', 
	_('Simple Social'),
	_('Add simple social icons to your posts'),
	'/lib/modules/simplesocial/icon.png');

$simplesocial = new simpleSocial();
api::addHook('posts::displayFunctions', array($simplesocial, 'displayButtons'));
unset($simplesocial);

?>
